﻿using System.Collections.ObjectModel;
using System.Globalization;
using System.Windows;
using System.Windows.Media;
using ThinkGeo.MapSuite;
using ThinkGeo.MapSuite.Drawing;
using ThinkGeo.MapSuite.Layers;
using ThinkGeo.MapSuite.Shapes;
using ThinkGeo.MapSuite.Styles;
using ThinkGeo.MapSuite.Wpf;

namespace Post9109
{
    /// <summary>
    /// Interaction logic for MainWindow.xaml
    /// </summary>
    public partial class MainWindow : Window
    {
        public MainWindow()
        {
            InitializeComponent();
        }

        private void map_Loaded(object sender, RoutedEventArgs e)
        {
            map.MapUnit = GeographyUnit.DecimalDegree;

            map.MapTools.Logo.IsEnabled = false;
            
            var worldOverlay = new WorldStreetsAndImageryOverlay();
            map.Overlays.Add(worldOverlay);

            var scaleLineLayer = new ScaleLineAdornmentLayer()
            {
                Location = AdornmentLocation.LowerLeft,
                XOffsetInPixel = 10,
                YOffsetInPixel = -10,
                UnitSystem = ScaleLineUnitSystem.ImperialAndMetric
            };
            scaleLineLayer.Pen = new GeoPen(new GeoSolidBrush(GeoColor.SimpleColors.Black), 3.0f);
            scaleLineLayer.HaloPen = new GeoPen(new GeoSolidBrush(GeoColor.SimpleColors.White), 7.0f);
            scaleLineLayer.TextStyle.HaloPen = new GeoPen(new GeoSolidBrush(GeoColor.SimpleColors.White), 2.0f);
            scaleLineLayer.TextStyle.Font = new GeoFont("Arial", 10.0f);
            map.AdornmentOverlay.Layers.Add(scaleLineLayer);

            MouseCoordinateAdornmentLayer mouseCoordinateAdornmentLayer = new MouseCoordinateAdornmentLayer();
            map.AdornmentOverlay.Layers.Add("mouseCoordinate", mouseCoordinateAdornmentLayer);

            map.MouseMove += Map_MouseMove1;

            map.CurrentExtent = new ThinkGeo.MapSuite.Shapes.RectangleShape(-136.7578125, 55.72265625, 1.0546875, -42.890625);
            map.Refresh();
        }

        private void Map_MouseMove1(object sender, System.Windows.Input.MouseEventArgs e)
        {
            Point currentPoint = e.GetPosition(map);
            PointShape worldPoint = ExtentHelper.ToWorldCoordinate(map.CurrentExtent, new ScreenPointF((float)currentPoint.X, (float)currentPoint.Y), (float)map.ActualWidth, (float)map.ActualHeight);

            string x = worldPoint.X.ToString("f6", CultureInfo.InvariantCulture);
            string y = worldPoint.Y.ToString("f6", CultureInfo.InvariantCulture);
            string coordinatesString = string.Format("X: {0}, Y: {1}", x, y);

            MouseCoordinateAdornmentLayer mouseCoordinateAdornmentLayer = map.AdornmentOverlay.Layers["mouseCoordinate"] as MouseCoordinateAdornmentLayer;
            mouseCoordinateAdornmentLayer.CoordinatesString = coordinatesString;

            map.AdornmentOverlay.Refresh();
        }
    }

    public class MouseCoordinateAdornmentLayer : AdornmentLayer
    {
        string coordinatesString;
        GeoFont font;
        GeoBrush brush;
        GeoPen haloPen;
        ScreenPointF[] screenPoints;

        public string CoordinatesString
        {
            get { return coordinatesString; }
            set { coordinatesString = value; }
        }

        public MouseCoordinateAdornmentLayer()
        {
            coordinatesString = " ";
            font = new GeoFont("Arial", 10);
            brush = new GeoSolidBrush(GeoColor.StandardColors.Black);
            haloPen = new GeoPen(GeoColor.StandardColors.White, 5);
        }


        protected override void DrawCore(GeoCanvas canvas, Collection<SimpleCandidate> labelsInAllLayers)
        {
            PointShape centerPoint = canvas.CurrentWorldExtent.LowerRightPoint;
            ScreenPointF boundaryPointF = ExtentHelper.ToScreenCoordinate(canvas.CurrentWorldExtent, centerPoint, canvas.Width, canvas.Height);
            ScreenPointF offsetPointF = new ScreenPointF((float)(boundaryPointF.X - 100), (float)(boundaryPointF.Y - 20));
            screenPoints = new ScreenPointF[] { offsetPointF };

            canvas.DrawText(coordinatesString, font, brush, haloPen, screenPoints, DrawingLevel.LabelLevel, 0, 0, 0);
        }
    }
}
